@@ -24,7 +24,6 @@ from pynmeagps.nmeahelpers import (
     dmm2ddd,
     ddd2dmm,
     list2csv,
-    int2hexstr,
     calc_checksum,
 )
 
@@ -66,7 +65,7 @@ class NMEAMessage:
             and msgID != "UBX"
         ):
             raise nme.NMEAMessageError(
-                f"Unknown msgID {msgID} msgmode {('GET','SET','POLL')[msgmode]}."
+                f"Unknown msgID {talker}{msgID}, msgmode {('GET','SET','POLL')[msgmode]}."
             )
 
         self._mode = msgmode
@@ -345,14 +344,26 @@ class NMEAMessage:
         output += "*" + self._checksum + "\r\n"
         return output.encode("utf-8")  # convert str to bytes
 
+    @property
+    def identity(self) -> str:
+        """
+        Identity getter.
+
+        :return: message identity e.g. GNGSA
+        :rtype: str
+        """
+
+        return self._talker + self._msgID
+
     @property
     def talker(self) -> str:
         """
         Talker getter.
 
-        :return: talker
+        :return: talker e.g. GN
         :rtype: str
         """
+
         return self._talker
 
     @property
@@ -360,7 +371,7 @@ class NMEAMessage:
         """
         Message id getter.
 
-        :return: message id
+        :return: message id e.g. GSA
         :rtype: str
         """
 
